@@ -1,6 +1,6 @@
 # coding:utf-8
 def __start() -> None:
-    JY = '''\
+    JY: str = '''\
 .------..------.
 |J.--. ||Y.--. |
 | :(): || (\/) |
@@ -8,7 +8,7 @@ def __start() -> None:
 | '--'J|| '--'Y|
 `------'`------'\
 '''
-    I_LIKE_JY = '''\
+    I_LIKE_JY: str = '''\
 .------.     .------..------..------..------.     .------..------.
 |I.--. |.-.  |L.--. ||I.--. ||K.--. ||E.--. |.-.  |J.--. ||Y.--. |
 | (\/) ((5)) | :/\: || (\/) || :/\: || (\/) ((5)) | :(): || (\/) |
@@ -24,10 +24,10 @@ def __start() -> None:
     from .version import ver
     from ..version import ver as fxxkpy_ver
 
-    content = JY if randint(1, 97) - 1 else I_LIKE_JY
-    color = '' if not randint(0, 2) else Fore.GREEN if not randint(0, 4) else Fore.YELLOW if randint(0, 1) else Fore.BLUE
+    content: str = JY if randint(1, 97) - 1 else I_LIKE_JY
+    color: str = "" if not randint(0, 2) else Fore.GREEN if not randint(0, 4) else Fore.YELLOW if randint(0, 1) else Fore.BLUE
     print(f"{color}JY {ver} (FxxkPy {fxxkpy_ver})")
-    print(content, end='')
+    print(content, end="")
     print(Style.RESET_ALL)
 
     del randint, version_info, Fore, Style, ver, color
