@@ -3,7 +3,7 @@
 class c(object):
     # printf方法
     def printf(content) -> None:
-        print(content, end='')
+        print(content, end="")
 
 
 # c++类
@@ -12,15 +12,17 @@ class cpp(object):
     class __Cout(object):
         # << 方法
         def __lshift__(self, other: str) -> "cpp.__Cout":
-            print(other, end='')
+            print(other, end="")
             return self
 
-    cout = __Cout()
-    endl = '\n'
+    cout: __Cout = __Cout()
+    endl: str = "\n"
 
 
 # Java类
 class java(object):
-    class System():
-        class out():
-            println = print
+    class System(object):
+        class out(object):
+            from types import FunctionType
+            println: FunctionType = print
+            del FunctionType
